==> medlogics-common-classes-1.1-20251001.051945-417.jar: com/floreantpos/model/dao/BedFeatureDAO.java <==
package com.floreantpos.model.dao;

import java.io.Serializable;

import org.apache.commons.lang3.StringUtils;
import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Restrictions;

import com.floreantpos.PosException;
import com.floreantpos.model.BedFeature;
import com.floreantpos.swing.PaginatedListModel;

public class BedFeatureDAO extends BaseBedFeatureDAO {

	/**
	 * Default constructor.  Can be used in place of getInstance()
	 */
	public BedFeatureDAO() {
	}

	public void loadData(PaginatedListModel<BedFeature> tableModel, String name, String outletId) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(getReferenceClass());
			if (StringUtils.isNotBlank(outletId)) {
				criteria.add(Restrictions.eq(BedFeature.PROP_OUTLET_ID, outletId));
			}
			addDeletedFilter(criteria);
			if (StringUtils.isNotBlank(name)) {
				criteria.add(Restrictions.eq(BedFeature.PROP_NAME, name));
			}
			tableModel.setNumRows(rowCount(criteria));
			criteria.setFirstResult(tableModel.getCurrentRowIndex());
			criteria.setMaxResults(tableModel.getPageSize());
			tableModel.setData(criteria.list());
		}
	}

	@Override
	protected Serializable save(Object obj, Session s) {
		updateTime(obj);
		return super.save(obj, s);
	}

	@Override
	protected void update(Object obj, Session s) {
		updateTime(obj);
		super.update(obj, s);
	}

	@Override
	protected void saveOrUpdate(Object obj, Session s) {
		updateTime(obj);
		super.saveOrUpdate(obj, s);
	}

	@Override
	protected void delete(Object obj, Session session) {
		BedFeature data = (BedFeature) obj;
		if (data == null) {
			throw new PosException("Data not found.");
		}
		data.setDeleted(Boolean.TRUE);
		saveOrUpdate(data, session);
	}
}

==> medlogics-common-classes-1.6.0.jar: com/floreantpos/model/dao/BedFeatureDAO.java <==
package com.floreantpos.model.dao;

import java.io.Serializable;

import org.apache.commons.lang3.StringUtils;
import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Restrictions;

import com.floreantpos.PosException;
import com.floreantpos.model.BedFeature;
import com.floreantpos.swing.PaginatedListModel;

public class BedFeatureDAO extends BaseBedFeatureDAO {

	/**
	 * Default constructor.  Can be used in place of getInstance()
	 */
	public BedFeatureDAO() {
	}

	public void loadData(PaginatedListModel<BedFeature> tableModel, String name) {
		try (Session session = createNewSession()) {
			Criteria criteria = session.createCriteria(getReferenceClass());
			addDeletedFilter(criteria);
			if (StringUtils.isNotBlank(name)) {
				criteria.add(Restrictions.eq(BedFeature.PROP_NAME, name));
			}
			tableModel.setNumRows(rowCount(criteria));
			criteria.setFirstResult(tableModel.getCurrentRowIndex());
			criteria.setMaxResults(tableModel.getPageSize());
			tableModel.setData(criteria.list());
		}
	}

	@Override
	protected Serializable save(Object obj, Session s) {
		updateTime(obj);
		return super.save(obj, s);
	}

	@Override
	protected void update(Object obj, Session s) {
		updateTime(obj);
		super.update(obj, s);
	}

	@Override
	protected void saveOrUpdate(Object obj, Session s) {
		updateTime(obj);
		super.saveOrUpdate(obj, s);
	}

	@Override
	protected void delete(Object obj, Session session) {
		BedFeature data = (BedFeature) obj;
		if (data == null) {
			throw new PosException("Data not found.");
		}
		data.setDeleted(Boolean.TRUE);
		saveOrUpdate(data, session);
	}
}
